@@ -8,14 +8,14 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.21 $
-    \date   create:2002/08/04 update:$Date: 2003/03/02 13:03:09 $
+    \version $Revision: 1.30 $
+    \date   create:2002/08/04 update:$Date: 2003/06/08 13:44:53 $
 */
 #include<IA32MemoryManager.h>
-#include<monaIdt.h>
-#include<monaVga.h>
-#include<monaKernel.h>
-#include<monaOperator.h>
+#include<kernel.h>
+#include<operator.h>
+#include<io.h>
+#include<global.h>
 
 /*!
     \brief get class Name
@@ -79,6 +79,8 @@ void* IA32MemoryManager::allocateMemory(size_t size) {
     this->printInfo("allocate memory");
 #endif
 
+    usedMemorySize_ += size;
+
     /* return address of allocated memory */
     return (void*)usedBlock->startAddress;
 }
@@ -107,6 +109,7 @@ void IA32MemoryManager::freeMemory(void* address) {
     this->printInfo("free memory");
 #endif
 
+    usedMemorySize_ -= targetAddress->size;
     return;
 }
 
@@ -119,7 +122,7 @@ void IA32MemoryManager::freeMemory(void* address) {
     \date   create:2002/08/08 update:
 */
 IA32MemoryManager::~IA32MemoryManager() {
-    _sys_printf("IA32MemoryManager:destructor\n");
+    g_console->printf("IA32MemoryManager:destructor\n");
 
 }
 
@@ -134,7 +137,7 @@ IA32MemoryManager::~IA32MemoryManager() {
     \date   create:2002/08/10 update:2003/01/03
 */
 //IA32MemoryManager::IA32MemoryManager():MEMORY_START(0x15000), MEMORY_END(0x150000) {
-IA32MemoryManager::IA32MemoryManager():MEMORY_START(0x150000), MEMORY_END(0x650000) {
+IA32MemoryManager::IA32MemoryManager():MEMORY_START(0x210000), MEMORY_END(0x390000) {
     /* first time, the number of free memory list is one. */
     freeEntry_ = (struct memoryEntry*)MEMORY_START;
     freeEntry_->size = MEMORY_END - MEMORY_START;
@@ -142,6 +145,8 @@ IA32MemoryManager::IA32MemoryManager():MEMORY_START(0x150000), MEMORY_END(0x6500
 
     /* there is no usedEntry */
     usedEntry_ = (struct memoryEntry*)NULL;
+
+    usedMemorySize_ = 0;
     return;
 }
 
@@ -177,12 +182,12 @@ void IA32MemoryManager::printInfo(char* str) const {
 
 //      for (entry = freeEntry_, i = 0; entry != (struct memoryEntry*)NULL; entry = entry->next, i++) {
 
-//          _sys_printf("%sfree block%d address=%d size=%d\n", str, i, entry, entry->size);
+//          g_console->printf("%sfree block%d address=%d size=%d\n", str, i, entry, entry->size);
 //      }
 
 //      for (entry = usedEntry_, i = 0; entry != (struct memoryEntry*)NULL; entry = entry->next, i++) {
 
-//          _sys_printf("%sused block%d address=%d size=%d\n", str, i, entry, entry->size);
+//          g_console->printf("%sused block%d address=%d size=%d\n", str, i, entry, entry->size);
 
 //      }
 
@@ -192,18 +197,18 @@ void IA32MemoryManager::printInfo(char* str) const {
     while (fentry || uentry) {
 
         if ((uentry && fentry > uentry) || (!fentry && uentry)) {
-            _sys_printf("[U%x-%x]", uentry->size, uentry);
+            g_console->printf("[U%x-%x]", uentry->size, uentry);
             uentry = uentry->next;
             continue;
         }
 
         if ((fentry && uentry > fentry) || (!uentry && fentry)) {
-            _sys_printf("[F%x-%x]", fentry->size, fentry);
+            g_console->printf("[F%x-%x]", fentry->size, fentry);
             fentry = fentry->next;
             continue;
         }
     }
-    _sys_printf(" %s \n", str);
+    g_console->printf(" %s \n", str);
     return;
 }
 
@@ -417,74 +422,24 @@ inline void IA32MemoryManager::flushTLB() const {
                  : /* no input  */ : "ax");
 }
 
-/*!
-    \brief set up GDT
+dword IA32MemoryManager::getTotalKernelMemory() {
 
-    set up descripter in GDT
-
-    \param index  index in GDT
-    \param base   base address of segment
-    \param limit  limit of segment
-    \param type   segment type
-    \param type32 type32
-
-    \author HigePon
-    \date   create:2002/12/31 update:
-*/
-void IA32MemoryManager::setGDT(word index, dword base, dword limit, byte type, byte type32) {
-
-    /* check index */
-    if (index >= GD_NUM) return;
-
-    /* set descriptor */
-    gdt_[index].baseL  = (word)(base & 0xffff);
-    gdt_[index].baseM  = (byte)((base >> 16) & 0xff);
-    gdt_[index].baseH  = (byte)((base >> 24) & 0xff);
-    gdt_[index].limitL = (word)(limit & 0xffff);
-    gdt_[index].limitH = (byte)((limit >> 16) & 0xff + type32);
-    gdt_[index].type   = type;
+    return (MEMORY_END - MEMORY_START);
 }
 
-/*!
-    \brief lgdt
+dword IA32MemoryManager::getUsedMemory() {
 
-    load adress and limit to gdtr register
-
-    \author HigePon
-    \date   create:2002/12/31 update:
-*/
-inline void IA32MemoryManager::lgdt() const {
-
-    GDTR gdtr;
-    gdtr.base  = (dword)gdt_;
-    gdtr.limit = sizeof(GDT) * GD_NUM - 1;
-    asm volatile("lgdt %0\n" : /* no output */ : "m" (gdtr));
+    return usedMemorySize_;
 }
 
-/*!
-    \brief reset GDT
+dword IA32MemoryManager::getTotalMemory() {
 
-    at secondboot.asm, set up GDT temporary.
-    here, set up GDT.
+    /* you should disable interrupt */
 
-    \author HigePon
-    \date   create:2002/12/31 update:
-*/
-void IA32MemoryManager::resetGDT() {
-
-    gdt_ = (GDT*)malloc(GD_NUM * sizeof(GDT));
-    if (gdt_ == NULL) panic("memory allocate error:GDT");
-
-    setGDT(0, 0, 0, 0, 0);
-    setGDT(1, 0, 0xFFFFFFFF, SYS_CODE , 0);
-    setGDT(2, 0, 0xFFFFFFFF, SYS_DATA , 0);
-    setGDT(3, 0, 0x00C00000, SYS_STACK, 0);
-    setGDT(4, 0, 0x00000067, SYS_TSS  , 0);
-    setGDT(5, 0, 0x00000067, SYS_TSS  , 0);
-    setGDT(6, 0, 0x00000067, SYS_LDT  , 0);
-
-    /* system code segment for task switch */
-    setGDT(7, 0, 0xFFFFFFFF, SYS_CODE , 0);
-    lgdt();
-    return;
+    dword result;
+    outportb(0x70, 0x31);
+    result = inportb(0x71);
+    result /= 4;
+    result += 1; /* +1MB */
+    return result;
 }
