@@ -8,12 +8,12 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.11 $
-    \date   create:2002/10/12 update:$Date: 2003/03/08 14:37:24 $
+    \version $Revision: 1.14 $
+    \date   create:2002/10/12 update:$Date: 2003/03/23 14:56:19 $
 */
 #include<KeyBoardManager.h>
-#include<monaVga.h>
-#include<monaOperator.h>
+#include<global.h>
+#include<operator.h>
 
 const int KeyBoardManager::keyMap_[128] = {
         0        , KEY_ESC  , '1'          , '2'           , '3'       , '4'            , '5'          , '6'      ,
@@ -107,7 +107,7 @@ void KeyBoardManager::setKeyScanCode(byte scancode) {
     byte keycode   = 0; /* keycode       */
     byte modifiers = 0; /* key modifiers */
 
-    //    _sys_printf("scancode=%x ", scancode);
+    //    g_console->printf("scancode=%x ", scancode);
 
     /* first, check some scancodes */
     switch(scancode) {
@@ -179,8 +179,6 @@ void KeyBoardManager::setKeyScanCode(byte scancode) {
     keyInfo_[keyBufIndex_].keycode   = keycode;
     keyInfo_[keyBufIndex_].modifiers = modifiers;
 
-    keyQueue_.push(keyInfo_[keyBufIndex_]);
-
     //    printInfo(keycode, modifiers);
     return;
 }
@@ -195,7 +193,7 @@ void KeyBoardManager::setKeyScanCode(byte scancode) {
 */
 void KeyBoardManager::printInfo(byte keycode, byte modifiers) const {
 
-    _sys_printf("%s %s%s%s%s%s char=\"%c\" \n", (modifiers & KEY_MODIFIER_DOWN )? "down" : "up  "
+    g_console->printf("%s %s%s%s%s%s char=\"%c\" \n", (modifiers & KEY_MODIFIER_DOWN )? "down" : "up  "
                                    , (modifiers & KEY_MODIFIER_SHIFT)? "shift": ""
                                    , (modifiers & KEY_MODIFIER_CTRL )? "ctrl" : ""
                                    , (modifiers & KEY_MODIFIER_ALT  )? "alt"  : ""
@@ -205,21 +203,3 @@ void KeyBoardManager::printInfo(byte keycode, byte modifiers) const {
     return;
 }
 
-/*!
-    \brief get Character in key buffer
-
-    \author HigePon
-    \date   create:2003/01/23 update:2002/10/25
-*/
-char KeyBoardManager::getCharacter() {
-
-      if (keyQueue_.empty()) return -1;
-
-      KeyInfo info = keyQueue_.back();
-      keyQueue_.pop();
-
-      if (info.modifiers & KEY_MODIFIER_UP) return -1;
-      if (info.keycode < 'a' && info.keycode > 'z') return -1;
-
-      return (char)(info.keycode);
-}
