@@ -8,12 +8,12 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.6 $
-    \date   create:2003/01/30 update:$Date: 2003/03/21 14:29:51 $
+    \version $Revision: 1.9 $
+    \date   create:2003/01/30 update:$Date: 2003/07/16 11:22:59 $
 */
 
-#include<semaphore.h>
-#include<monaKernel.h>
+#include<Semaphore.h>
+#include<kernel.h>
 #include<io.h>
 #include<global.h>
 
@@ -24,10 +24,10 @@
     \author HigePon
     \date   create:2003/01/31 update:2003/02/01
 */
-int semaphore_up(semaphore* sem) {
+void Semaphore::up(semaphore* sem) {
 
     (*sem)++;
-    return 0;
+    return;
 }
 
 /*!
@@ -37,7 +37,7 @@ int semaphore_up(semaphore* sem) {
     \author HigePon
     \date   create:2003/01/31 update:2003/03/21
 */
-int semaphore_down(semaphore* sem) {
+int Semaphore::down(semaphore* sem) {
 
     dword eflags = get_eflags();
     disableInterrupt();
