@@ -8,10 +8,10 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.1.1.1 $
-    \date   create:2002/07/21 update:$Date: 2002/11/16 15:29:53 $
+    \version $Revision: 1.2 $
+    \date   create:2002/07/21 update:$Date: 2003/03/24 15:53:04 $
 */
-#include <monaKernel.h>
+#include <kernel.h>
 
 /*!
     \brief  mona kernel start at this point
