@@ -8,13 +8,13 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.2 $
-    \date   create:2002/12/31 update:$Date: 2003/02/22 13:29:51 $
+    \version $Revision: 1.3 $
+    \date   create:2002/12/31 update:$Date: 2003/03/23 14:56:20 $
 */
 #ifndef _MONA_SYSTEMINFO_
 #define _MONA_SYSTEMINFO_
 
-#include<monaTypes.h>
+#include<types.h>
 #include<VirtualConsole.h>
 
 #define INTEL          0
