@@ -6,19 +6,20 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.7 $
-    \date   create:2003/03/09 update:$Date: 2003/03/22 15:29:45 $
+    \version $Revision: 1.9 $
+    \date   create:2003/03/09 update:$Date: 2003/07/19 08:35:11 $
 */
 
 #ifndef _MONA_DISP_
 #define _MONA_DISP_
 
-#include <monaTypes.h>
+#include <types.h>
 
 void disp_name1();
 void disp_name2();
 void disp_name3();
 void disp_name4();
+void disp_process();
 void disp_kthread_info();
 void disp_fd_demo();
 void kthread_idle();
