@@ -6,14 +6,14 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.3 $
-    \date   create:2003/03/08 update:$Date: 2003/03/09 14:06:55 $
+    \version $Revision: 1.4 $
+    \date   create:2003/03/08 update:$Date: 2003/03/23 14:56:20 $
 */
 
 #ifndef _MONA_IO_
 #define _MONA_IO_
 
-#include <monaTypes.h>
+#include <types.h>
 
 byte inportb(dword);
 void outportb(dword, byte);
