@@ -6,14 +6,15 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.14 $
-    \date   create:2003/03/01 update:$Date: 2003/03/22 09:54:01 $
+    \version $Revision: 1.16 $
+    \date   create:2003/03/01 update:$Date: 2003/07/06 12:26:36 $
 */
 
 #ifndef _MONA_KTHREAD_
 #define _MONA_KTHREAD_
 
-#include<monaTypes.h>
+#include<types.h>
+#include<kernel.h>
 
 /*! struct for kernel thread */
 typedef struct Kthread {
