@@ -6,14 +6,14 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.1 $
-    \date   create:2003/03/09 update:$Date: 2003/03/09 10:45:18 $
+    \version $Revision: 1.2 $
+    \date   create:2003/03/09 update:$Date: 2003/03/23 14:56:20 $
 */
 
 #ifndef _MONA_RTC_
 #define _MONA_RTC_
 
-#include <monaTypes.h>
+#include <types.h>
 #include <io.h>
 
 typedef struct Date {
