@@ -58,9 +58,9 @@ _STLP_END_NAMESPACE
 # else
 #  include <cstdlib>
 #  include <cstdio>
+//#  include <global.h>
 ////#  define _STLP_THROW_MSG(ex,msg)  puts(msg),_STLP_ABORT()
-#include <monaVga.h>
-#  define _STLP_THROW_MSG(ex,msg)  _sys_printf((char*)msg)
+#  define _STLP_THROW_MSG(ex,msg)  /*g_console->printf((char*)msg) */
 # endif
 #endif
 
