@@ -6,8 +6,8 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.3 $
-    \date   create:2003/03/22 update:$Date: 2003/03/22 10:32:01 $
+    \version $Revision: 1.4 $
+    \date   create:2003/03/22 update:$Date: 2003/03/23 14:42:20 $
 */
 
 #include<syscalls.h>
@@ -37,7 +37,7 @@ void syscall_entrance() {
 
 void syscall_kthread_yield() {
 
-    asm volatile("movw $0, %ebx \n"
+    asm volatile("mov $0, %ebx  \n"
                  "int $0x80       "
                  );
     return;
